==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_basics/html_web_basics/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Basics", "index.html", [
    [ "Organization", "index.html#Organization", null ],
    [ "StarPU Applications, setting up Your Own Code", "StarPUApplications.html", [
      [ "Setting Flags for Compiling, Linking and Running Applications", "StarPUApplications.html#SettingFlagsForCompilingLinkingAndRunningApplications", null ],
      [ "Integrating StarPU in a Build System", "StarPUApplications.html#IntegratingStarPUInABuildSystem", [
        [ "Integrating StarPU in a Make Build System", "StarPUApplications.html#StarPUInMake", null ],
        [ "Integrating StarPU in a CMake Build System", "StarPUApplications.html#StarPUInCMake", null ]
      ] ],
      [ "Running a Basic StarPU Application", "StarPUApplications.html#RunningABasicStarPUApplication", null ],
      [ "Running a Basic StarPU Application on Microsoft Visual C", "StarPUApplications.html#RunningABasicStarPUApplicationOnMicrosoft", null ],
      [ "Kernel Threads Started by StarPU", "StarPUApplications.html#KernelThreadsStartedByStarPU", null ],
      [ "Enabling OpenCL", "StarPUApplications.html#EnablingOpenCL", null ],
      [ "Performance Model Files", "StarPUApplications.html#Storing", null ]
    ] ],
    [ "Basic Examples", "BasicExamples.html", [
      [ "Hello World", "BasicExamples.html#HelloWorldUsingStarPUAPI", [
        [ "Required Headers", "BasicExamples.html#RequiredHeaders", null ],
        [ "Defining A Codelet", "BasicExamples.html#DefiningACodelet", null ],
        [ "Submitting A Task", "BasicExamples.html#SubmittingATask", null ],
        [ "Execution Of Hello World", "BasicExamples.html#ExecutionOfHelloWorld", null ],
        [ "Passing Arguments To The Codelet", "BasicExamples.html#PassingArgumentsToTheCodelet", null ],
        [ "Defining A Callback", "BasicExamples.html#DefiningACallback", null ],
        [ "Where To Execute A Codelet", "BasicExamples.html#WhereToExecuteACodelet", null ]
      ] ],
      [ "Vector Scaling", "BasicExamples.html#VectorScalingUsingStarPUAPI", [
        [ "Source Code of Vector Scaling", "BasicExamples.html#SourceCodeOfVectorScaling", null ],
        [ "Execution of Vector Scaling", "BasicExamples.html#ExecutionOfVectorScaling", null ]
      ] ],
      [ "Vector Scaling on an Hybrid CPU/GPU Machine", "BasicExamples.html#VectorScalingOnAnHybridCPUGPUMachine", [
        [ "Definition of the CUDA Kernel", "BasicExamples.html#DefinitionOfTheCUDAKernel", null ],
        [ "Definition of the OpenCL Kernel", "BasicExamples.html#DefinitionOfTheOpenCLKernel", null ],
        [ "Definition of the Main Code", "BasicExamples.html#DefinitionOfTheMainCode", null ],
        [ "Execution of Hybrid Vector Scaling", "BasicExamples.html#ExecutionOfHybridVectorScaling", null ]
      ] ]
    ] ],
    [ "Full source code for the ’Scaling a Vector’ example", "FullSourceCodeVectorScal.html", [
      [ "Main Application", "FullSourceCodeVectorScal.html#MainApplication", null ],
      [ "CPU Kernel", "FullSourceCodeVectorScal.html#CPUKernel", null ],
      [ "CUDA Kernel", "FullSourceCodeVectorScal.html#CUDAKernel", null ],
      [ "OpenCL Kernel", "FullSourceCodeVectorScal.html#OpenCLKernel", [
        [ "Invoking the Kernel", "FullSourceCodeVectorScal.html#InvokingtheKernel", null ],
        [ "Source of the Kernel", "FullSourceCodeVectorScal.html#SourceoftheKernel", null ]
      ] ]
    ] ],
    [ "Tasks In StarPU", "TasksInStarPU.html", [
      [ "Task Granularity", "TasksInStarPU.html#TaskGranularity", null ],
      [ "Task Submission", "TasksInStarPU.html#TaskSubmission", null ],
      [ "Task Priorities", "TasksInStarPU.html#TaskPriorities", null ],
      [ "Setting Many Data Handles For a Task", "TasksInStarPU.html#SettingManyDataHandlesForATask", null ],
      [ "Setting a Variable Number Of Data Handles For a Task", "TasksInStarPU.html#SettingVariableDataHandlesForATask", null ],
      [ "Insert Task Utility", "TasksInStarPU.html#InsertTaskUtility", null ]
    ] ],
    [ "Data Management", "DataManagement.html", [
      [ "Data Interface", "DataManagement.html#DataInterface", [
        [ "Variable Data Interface", "DataManagement.html#VariableDataInterface", null ],
        [ "Vector Data Interface", "DataManagement.html#VectorDataInterface", null ],
        [ "Matrix Data Interface", "DataManagement.html#MatrixDataInterface", null ],
        [ "Block Data Interface", "DataManagement.html#BlockDataInterface", null ],
        [ "Tensor Data Interface", "DataManagement.html#TensorDataInterface", null ],
        [ "Ndim Data Interface", "DataManagement.html#NdimDataInterface", null ],
        [ "BCSR Data Interface", "DataManagement.html#BCSRDataInterface", null ],
        [ "CSR Data Interface", "DataManagement.html#CSRDataInterface", null ],
        [ "COO Data Interface", "DataManagement.html#COODataInterface", null ]
      ] ],
      [ "Partitioning Data", "DataManagement.html#PartitioningData", null ],
      [ "Asynchronous Partitioning", "DataManagement.html#AsynchronousPartitioning", null ],
      [ "Commute Data Access", "DataManagement.html#DataCommute", null ],
      [ "Data Reduction", "DataManagement.html#DataReduction", null ],
      [ "Concurrent Data Accesses", "DataManagement.html#ConcurrentDataAccess", null ],
      [ "Temporary Buffers", "DataManagement.html#TemporaryBuffers", [
        [ "Temporary Data", "DataManagement.html#TemporaryData", null ],
        [ "Scratch Data", "DataManagement.html#ScratchData", null ]
      ] ]
    ] ],
    [ "Scheduling", "Scheduling.html", [
      [ "Task Scheduling Policies", "Scheduling.html#TaskSchedulingPolicy", [
        [ "Non Performance Modelling Policies", "Scheduling.html#NonPerformanceModelingPolicies", null ],
        [ "Performance Model-Based Task Scheduling Policies", "Scheduling.html#DMTaskSchedulingPolicy", null ],
        [ "Modularized Schedulers", "Scheduling.html#ExistingModularizedSchedulers", null ]
      ] ],
      [ "Task Distribution Vs Data Transfer", "Scheduling.html#TaskDistributionVsDataTransfer", null ]
    ] ],
    [ "Examples in StarPU Sources", "ExamplesInStarPUSources.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"",
"group__API__Bitmap.html#ga502f85817c9a3e390905374f201ee3da",
"group__API__Codelet__And__Tasks.html#ga59e1f4653a39359c060b4d10bc0a39bf",
"group__API__Data__Interfaces.html#aaff7aa638a24957eb76c5c40f96cddbe",
"group__API__Data__Interfaces.html#ga7ea069447f11e836d7b709c97d90b570",
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cac55e5bac53f8121d107f4bebf2d26155",
"group__API__Data__Partition.html#ga6a3f729055f14384e7397d2815a2c9a5",
"group__API__HIP__Extensions.html",
"group__API__Insert__Task.html#ga8083ef4e1927b0989435d6bd31fd9083",
"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd",
"group__API__Miscellaneous__Helpers.html#gab4c1b68e62245662b1d02b2f8b65b596",
"group__API__Modularized__Scheduler.html#structstarpu__sched__tree",
"group__API__OpenMP__Runtime__Support.html#gadaf4576512b9ecc58c71cb36a87105b7",
"group__API__Perf__Monitoring.html#gaba3d2e0ac27cf891689bd62805656d5f",
"group__API__Performance__Model.html#gac4075eddef3625eccbbc9f1670c69244",
"group__API__SC__Hypervisor.html#ga35b9d502acdeb864bbc3cb429e255c22",
"group__API__Scheduler__Toolbox.html#gae94f5e2adfa9b6b61cccadd80a74073d",
"group__API__Standard__Memory__Library.html#ga2abe959e39acfb75c7c0652706dfe84c",
"group__API__Threads.html#gaf16bdf5df80097a4fbd08b23af68f829",
"group__API__Workers__Properties.html#gad7c443d1341e4976d63fb5d77e74bf09",
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html",
"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__recv__detached.html",
"starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80",
"starpu__thread_8h.html#ad701c76f95cc5f72336b2e31c249fd17"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_basics/html_web_basics/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Basics", "index.html", [
    [ "StarPU Applications, setting up Your Own Code", "StarPUApplications.html", [
      [ "Setting Flags for Compiling, Linking and Running Applications", "StarPUApplications.html#SettingFlagsForCompilingLinkingAndRunningApplications", null ],
      [ "Integrating StarPU in a Build System", "StarPUApplications.html#IntegratingStarPUInABuildSystem", [
        [ "Integrating StarPU in a Make Build System", "StarPUApplications.html#StarPUInMake", null ],
        [ "Integrating StarPU in a CMake Build System", "StarPUApplications.html#StarPUInCMake", null ]
      ] ],
      [ "Running a Basic StarPU Application", "StarPUApplications.html#RunningABasicStarPUApplication", null ],
      [ "Running a Basic StarPU Application on Microsoft Visual C", "StarPUApplications.html#RunningABasicStarPUApplicationOnMicrosoft", null ],
      [ "Kernel Threads Started by StarPU", "StarPUApplications.html#KernelThreadsStartedByStarPU", null ],
      [ "Enabling OpenCL", "StarPUApplications.html#EnablingOpenCL", null ],
      [ "Storing Performance Model Files", "StarPUApplications.html#Storing_Performance_Model_Files", null ]
    ] ],
    [ "Basic Examples", "BasicExamples.html", [
      [ "Hello World", "BasicExamples.html#HelloWorldUsingStarPUAPI", [
        [ "Required Headers", "BasicExamples.html#RequiredHeaders", null ],
        [ "Defining A Codelet", "BasicExamples.html#DefiningACodelet", null ],
        [ "Submitting A Task", "BasicExamples.html#SubmittingATask", null ],
        [ "Execution Of Hello World", "BasicExamples.html#ExecutionOfHelloWorld", null ],
        [ "Passing Arguments To The Codelet", "BasicExamples.html#PassingArgumentsToTheCodelet", null ],
        [ "Defining A Callback", "BasicExamples.html#DefiningACallback", null ],
        [ "Where To Execute A Codelet", "BasicExamples.html#WhereToExecuteACodelet", null ]
      ] ],
      [ "Vector Scaling", "BasicExamples.html#VectorScalingUsingStarPUAPI", [
        [ "Source Code of Vector Scaling", "BasicExamples.html#SourceCodeOfVectorScaling", null ],
        [ "Execution of Vector Scaling", "BasicExamples.html#ExecutionOfVectorScaling", null ]
      ] ],
      [ "Vector Scaling on an Hybrid CPU/GPU Machine", "BasicExamples.html#VectorScalingOnAnHybridCPUGPUMachine", [
        [ "Definition of the CUDA Kernel", "BasicExamples.html#DefinitionOfTheCUDAKernel", null ],
        [ "Definition of the OpenCL Kernel", "BasicExamples.html#DefinitionOfTheOpenCLKernel", null ],
        [ "Definition of the Main Code", "BasicExamples.html#DefinitionOfTheMainCode", null ],
        [ "Execution of Hybrid Vector Scaling", "BasicExamples.html#ExecutionOfHybridVectorScaling", null ]
      ] ]
    ] ],
    [ "Full source code for the ’Scaling a Vector’ example", "FullSourceCodeVectorScal.html", [
      [ "Main Application", "FullSourceCodeVectorScal.html#MainApplication", null ],
      [ "CPU Kernel", "FullSourceCodeVectorScal.html#CPUKernel", null ],
      [ "CUDA Kernel", "FullSourceCodeVectorScal.html#CUDAKernel", null ],
      [ "OpenCL Kernel", "FullSourceCodeVectorScal.html#OpenCLKernel", [
        [ "Invoking the Kernel", "FullSourceCodeVectorScal.html#InvokingtheKernel", null ],
        [ "Source of the Kernel", "FullSourceCodeVectorScal.html#SourceoftheKernel", null ]
      ] ]
    ] ],
    [ "Tasks In StarPU", "TasksInStarPU.html", [
      [ "Task Granularity", "TasksInStarPU.html#TaskGranularity", null ],
      [ "Task Submission", "TasksInStarPU.html#TaskSubmission", null ],
      [ "Task Priorities", "TasksInStarPU.html#TaskPriorities", null ],
      [ "Setting Many Data Handles For a Task", "TasksInStarPU.html#SettingManyDataHandlesForATask", null ],
      [ "Setting a Variable Number Of Data Handles For a Task", "TasksInStarPU.html#SettingVariableDataHandlesForATask", null ],
      [ "Insert Task Utility", "TasksInStarPU.html#InsertTaskUtility", null ],
      [ "Other Task Utility Functions", "TasksInStarPU.html#OtherTaskUtility", null ]
    ] ],
    [ "Data Management", "DataManagement.html", [
      [ "Data Interface", "DataManagement.html#DataInterface", [
        [ "Variable Data Interface", "DataManagement.html#VariableDataInterface", null ],
        [ "Vector Data Interface", "DataManagement.html#VectorDataInterface", null ],
        [ "Matrix Data Interface", "DataManagement.html#MatrixDataInterface", null ],
        [ "Block Data Interface", "DataManagement.html#BlockDataInterface", null ],
        [ "Tensor Data Interface", "DataManagement.html#TensorDataInterface", null ],
        [ "Ndim Data Interface", "DataManagement.html#NdimDataInterface", null ],
        [ "BCSR Data Interface", "DataManagement.html#BCSRDataInterface", null ],
        [ "CSR Data Interface", "DataManagement.html#CSRDataInterface", null ],
        [ "COO Data Interface", "DataManagement.html#COODataInterface", null ]
      ] ],
      [ "Partitioning Data", "DataManagement.html#PartitioningData", null ],
      [ "Asynchronous Partitioning", "DataManagement.html#AsynchronousPartitioning", null ],
      [ "Commute Data Access", "DataManagement.html#DataCommute", null ],
      [ "Data Reduction", "DataManagement.html#DataReduction", null ],
      [ "Concurrent Data Accesses", "DataManagement.html#ConcurrentDataAccess", null ],
      [ "Temporary Buffers", "DataManagement.html#TemporaryBuffers", [
        [ "Temporary Data", "DataManagement.html#TemporaryData", null ],
        [ "Scratch Data", "DataManagement.html#ScratchData", null ]
      ] ]
    ] ],
    [ "Scheduling", "Scheduling.html", [
      [ "Task Scheduling Policies", "Scheduling.html#TaskSchedulingPolicy", [
        [ "Non Performance Modelling Policies", "Scheduling.html#NonPerformanceModelingPolicies", null ],
        [ "Performance Model-Based Task Scheduling Policies", "Scheduling.html#DMTaskSchedulingPolicy", null ],
        [ "Modularized Schedulers", "Scheduling.html#ExistingModularizedSchedulers", null ]
      ] ],
      [ "Task Distribution Vs Data Transfer", "Scheduling.html#TaskDistributionVsDataTransfer", null ]
    ] ],
    [ "Examples in StarPU Sources", "ExamplesInStarPUSources.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BasicExamples.html",
"group__API__Codelet__And__Tasks.html#a84b67cae77eb44496f782910072b8279",
"group__API__Data__Interfaces.html#aaff7aa638a24957eb76c5c40f96cddbe",
"group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4",
"group__API__Fortran.html",
"group__API__Interop__Support.html#gaec539f82e7bc8fc9c2541b4a192486fb",
"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae",
"group__API__Parallel__Worker.html#ga777b13d6f49389771ce70e5c0fdfaf70",
"group__API__Profiling.html#ga858f465a2dcbcadb6169a7926e38a4d1",
"group__API__Scheduling__Policy.html#ga24154b37920144de18bca59090429d6d",
"group__API__Workers.html#ga3fa9784ddcf3fc9f496e33fe4cad54ce",
"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html",
"interfacestarpu__mod_1_1starpu__resume.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
